lists.arthurdejong.org
RSS feed

nss-pam-ldapd branch master updated. 0.9.10-9-ga8f4ed8

[Date Prev][Date Next] [Thread Prev][Thread Next]

nss-pam-ldapd branch master updated. 0.9.10-9-ga8f4ed8



This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "nss-pam-ldapd".

The branch, master has been updated
       via  a8f4ed81301d3e34b8b4f642b95c47677f947131 (commit)
      from  644bc6247d730b96b65fd66a46003442237bb5a0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
https://arthurdejong.org/git/nss-pam-ldapd/commit/?id=a8f4ed81301d3e34b8b4f642b95c47677f947131

commit a8f4ed81301d3e34b8b4f642b95c47677f947131
Author: Arthur de Jong <arthur@arthurdejong.org>
Date:   Tue Sep 17 18:45:50 2019 +0200

    Various spelling fixes

diff --git a/NEWS b/NEWS
index 62c4d92..c47d0bc 100644
--- a/NEWS
+++ b/NEWS
@@ -50,7 +50,7 @@ changes from 0.9.6 to 0.9.7
 * fix error when changing PAM user name (thanks 依云)
 * support substring expressions ${var:offset:length} in attribute mapping
   (thanks Giovanni Mascellani)
-* also honor the ignorecase option in PAM
+* also honour the ignorecase option in PAM
 
 
 changes from 0.9.5 to 0.9.6
diff --git a/common/expr.c b/common/expr.c
index 092ce7a..545828b 100644
--- a/common/expr.c
+++ b/common/expr.c
@@ -80,7 +80,7 @@ static const char *empty_expander(const char UNUSED(*name),
   return "";
 }
 
-/* definition of the parse functions (they call eachother) */
+/* definition of the parse functions (they call each other) */
 MUST_USE static const char *parse_dollar_expression(
               const char *str, int *ptr, char *buffer, size_t buflen,
               expr_expander_func expander, void *expander_arg);
@@ -165,7 +165,7 @@ MUST_USE static const char *parse_dollar_substring(
   if (length >= buflen)
     return NULL;
   /* everything's ok, copy data; we use memcpy instead of strncpy
-     because we already know the exact lenght in play */
+     because we already know the exact length in play */
   memcpy(buffer, varvalue + offset, length);
   buffer[length] = '\0';
   return buffer;
diff --git a/common/nslcd-prot.c b/common/nslcd-prot.c
index 87c0066..7ee91de 100644
--- a/common/nslcd-prot.c
+++ b/common/nslcd-prot.c
@@ -40,7 +40,7 @@
 #include "compat/socket.h"
 
 /* read timeout is 60 seconds because looking up stuff may take some time
-   write timeout is 10 secods because nslcd could be loaded with requests */
+   write timeout is 10 seconds because nslcd could be loaded with requests */
 #define READ_TIMEOUT 60 * 1000
 #define WRITE_TIMEOUT 10 * 1000
 
diff --git a/common/tio.c b/common/tio.c
index 8095dfb..71c2fdc 100644
--- a/common/tio.c
+++ b/common/tio.c
@@ -170,7 +170,7 @@ static int tio_wait(int fd, short events, int timeout,
       errno = ETIME;
       return -1;
     }
-    /* sanitiy check for moving clock */
+    /* sanity check for moving clock */
     if (t > timeout)
       t = timeout;
     /* wait for activity */
@@ -184,7 +184,7 @@ static int tio_wait(int fd, short events, int timeout,
       return -1;
     }
     else if ((errno != EINTR) && (errno != EAGAIN))
-      /* some error ocurred */
+      /* some error occurred */
       return -1;
     /* we just try again on EINTR or EAGAIN */
   }
@@ -422,7 +422,7 @@ int tio_write(TFILE *fp, const void *buf, size_t count)
   uint8_t *tmp;
   size_t newsz;
   const uint8_t *ptr = (const uint8_t *)buf;
-  /* keep filling the buffer until we have bufferred everything */
+  /* keep filling the buffer until we have buffered everything */
   while (count > 0)
   {
     /* figure out free size in buffer */
diff --git a/compat/attrs.h b/compat/attrs.h
index 0d13073..e4273a3 100644
--- a/compat/attrs.h
+++ b/compat/attrs.h
@@ -26,7 +26,7 @@
 #define GCC_VERSION(major, minor)                                           \
   ((__GNUC__ > (major)) || (__GNUC__ == (major) && __GNUC_MINOR__ >= (minor)))
 
-/* These are macros to use some gcc-specific flags in case the're available
+/* These are macros to use some gcc-specific flags in case they're available
    and otherwise define them to empty strings. This allows us to give
    the compiler some extra information.
    See http://gcc.gnu.org/onlinedocs/gcc/Attribute-Syntax.html
diff --git a/compat/ether.c b/compat/ether.c
index bda1718..1f28805 100644
--- a/compat/ether.c
+++ b/compat/ether.c
@@ -33,7 +33,7 @@
 
 #include "ether.h"
 
-/* these functions are not really reentrant */
+/* these functions are not really re-entrant */
 
 #ifndef HAVE_ETHER_ATON_R
 struct ether_addr *ether_aton_r(const char *asc, struct ether_addr *addr)
diff --git a/compat/getopt_long.c b/compat/getopt_long.c
index eba9079..c497a78 100644
--- a/compat/getopt_long.c
+++ b/compat/getopt_long.c
@@ -26,10 +26,10 @@
 #include "getopt_long.h"
 
 /* this is a (poor) getopt_long() replacement for systems that don't have it
-   (getopt_long() is generaly a GNU extention)
-   this implementation is by no meens flawless, especialy the optional 
arguments
-   to options and options following filenames is not quite right, allso
-   minimal error checking is provided
+   (this is generally a GNU extension)
+   this implementation is by no means flawless, especially the optional
+   arguments to options and options following filenames is not quite right,
+   also minimal error checking is performed
    */
 int getopt_long(int argc, char *const argv[],
                 const char *optstring,
diff --git a/compat/getopt_long.h b/compat/getopt_long.h
index 6182be3..e2b351c 100644
--- a/compat/getopt_long.h
+++ b/compat/getopt_long.h
@@ -36,10 +36,10 @@ struct option {
 };
 
 /* this is a (poor) getopt_long() replacement for systems that don't have it
-   (this is generaly a GNU extention)
-   this implementation is by no meens flawless, especialy the optional 
arguments
-   to options and options following filenames is not quite right, allso
-   minimal error checking
+   (this is generally a GNU extension)
+   this implementation is by no means flawless, especially the optional
+   arguments to options and options following filenames is not quite right,
+   also minimal error checking is performed
    */
 int getopt_long(int argc, char *const argv[],
                 const char *optstring,
diff --git a/compat/getpeercred.h b/compat/getpeercred.h
index 5f96cc1..c29d610 100644
--- a/compat/getpeercred.h
+++ b/compat/getpeercred.h
@@ -26,7 +26,7 @@
 
 /* This function tries to determine the (effective) user id, group id
    and process id of the other end of the specified socket.
-   Any of the uid, gid and pid paramaters may be NULL to not update
+   Any of the uid, gid and pid parameters may be NULL to not update
    that information.
    On success, zero is returned.  On error, -1 is returned, and errno
    is set appropriately. */
diff --git a/compat/nss_compat.h b/compat/nss_compat.h
index 755ce91..ac4ce2f 100644
--- a/compat/nss_compat.h
+++ b/compat/nss_compat.h
@@ -107,7 +107,7 @@ struct etherent {
 #endif /* not HAVE_STRUCT_ETHERENT */
 
 /* We also define struct __netgrent because its definition is
-   not publically available. This is taken from inet/netgroup.h
+   not publicly available. This is taken from inet/netgroup.h
    of the glibc (2.3.6) source tarball.
    The first part of the struct is the only part that is modified
    by our getnetgrent() function, all the other fields are not
diff --git a/configure.ac b/configure.ac
index 97b35cc..50310d1 100644
--- a/configure.ac
+++ b/configure.ac
@@ -415,7 +415,7 @@ AC_CHECK_DECLS([ether_aton, ether_ntoa],,, [
 
 # check to see if socklen_t is defined
 AC_CHECK_TYPE(socklen_t,,
-    AC_DEFINE(socklen_t, size_t, [Define to `size_t' if not defined 
elswhere.]), [
+    AC_DEFINE(socklen_t, size_t, [Define to `size_t' if not defined 
elsewhere.]), [
     #include <sys/types.h>
     #include <sys/socket.h>])
 
diff --git a/man/nslcd.conf.5.xml b/man/nslcd.conf.5.xml
index cf17daf..7a2bc5a 100644
--- a/man/nslcd.conf.5.xml
+++ b/man/nslcd.conf.5.xml
@@ -820,7 +820,7 @@
        The regular expression should be specified as a POSIX extended regular
        expression. The expression itself needs to be separated by slash (/)
        characters and the 'i' flag may be appended at the end to indicate
-       that the match should be case-insensetive.
+       that the match should be case-insensitive.
        The default value is
        <literal>/^[a-z0-9._@$()]([a-z0-9._@$() 
\\~-]*[a-z0-9._@$()~-])?$/i</literal>
       </para>
@@ -837,7 +837,7 @@
        Setting this to <literal>yes</literal> could open up the system
        to authorisation bypass vulnerabilities and introduce nscd cache 
poisoning
        vulnerabilities which allow denial of service.
-       The default is to perform case-sensitve filtering of LDAP search
+       The default is to perform case-sensitive filtering of LDAP search
        results for the above maps.
       </para>
      </listitem>
@@ -1081,7 +1081,7 @@
    <varlistentry>
     <term><literal>${attr:-word}</literal></term>
     <listitem><para>
-     (use default) will substitbute the value of the attribute or, if the
+     (use default) will substitute the value of the attribute or, if the
      attribute is not set or empty substitute the word
     </para></listitem>
    </varlistentry>
diff --git a/nslcd.h b/nslcd.h
index c9857d6..f6c028d 100644
--- a/nslcd.h
+++ b/nslcd.h
@@ -52,13 +52,13 @@
      INT32  - 32-bit integer value
      TYPE   - a typed field that is transferred using sizeof()
      STRING - a string length (32bit) followed by the string value (not
-              null-terminted) the string itself is assumed to be UTF-8
+              null-terminated) the string itself is assumed to be UTF-8
      STRINGLIST - a 32-bit number noting the number of strings followed by
                   the strings one at a time
 
    Furthermore the ADDRESS compound data type is defined as:
      INT32  type of address: e.g. AF_INET or AF_INET6
-     INT32  lenght of address
+     INT32  length of address
      RAW    the address itself
    With the ADDRESSLIST using the same construct as with STRINGLIST.
 
@@ -212,7 +212,7 @@
      STRING  password
    and the result value consists of:
      INT32   authc NSLCD_PAM_* result code
-     STRING  user name (the cannonical user name)
+     STRING  user name (the canonical user name)
      INT32   authz NSLCD_PAM_* result code
      STRING  authorisation error message
    If the username is empty in this request an attempt is made to
diff --git a/nslcd/attmap.h b/nslcd/attmap.h
index 81859ab..df0dd38 100644
--- a/nslcd/attmap.h
+++ b/nslcd/attmap.h
@@ -79,7 +79,7 @@ const char **filter_get_var(enum ldap_map_selector map);
 
 /* return a reference to the attribute mapping variable for the specified name
    the name is the name after the attmap_... variables above with the
-   underscode replaced by a dot (e.g passwd.homeDirectory) */
+   underscore replaced by a dot (e.g passwd.homeDirectory) */
 const char **attmap_get_var(enum ldap_map_selector map, const char *name);
 
 /* Set the attribute mapping of the variable to the value specified.
@@ -92,7 +92,7 @@ MUST_USE const char *attmap_set_mapping(const char **var, 
const char *value);
 const char *attmap_get_value(MYLDAP_ENTRY *entry, const char *attr,
                              char *buffer, size_t buflen);
 
-/* Add the attributes from attr to the set. The attr argumenent
+/* Add the attributes from attr to the set. The attr argument
    can either be an attribute or an attribute expression. */
 SET *attmap_add_attributes(SET *set, const char *attr);
 
diff --git a/nslcd/common.h b/nslcd/common.h
index 26fcf48..0a0cacd 100644
--- a/nslcd/common.h
+++ b/nslcd/common.h
@@ -39,7 +39,7 @@
 #include "cfg.h"
 
 /* macros for basic read and write operations, the following
-   ERROR_OUT* marcos define the action taken on errors
+   ERROR_OUT* macros define the action taken on errors
    the stream is not closed because the caller closes the
    stream */
 
@@ -156,7 +156,7 @@ void invalidator_do(enum ldap_map_selector map);
 #define BUFLEN_PASSWORD     128  /* passwords */
 #define BUFLEN_PASSWORDHASH 256  /* passwords hashes */
 #define BUFLEN_DN           512  /* distinguished names */
-#define BUFLEN_SAFEDN       600  /* escapedd dn */
+#define BUFLEN_SAFEDN       600  /* escaped dn */
 #define BUFLEN_FILTER      4096  /* search filters */
 #define BUFLEN_HOSTNAME     256  /* host names or FQDN (and safe version) */
 #define BUFLEN_MESSAGE     1024  /* message strings */
diff --git a/nslcd/daemonize.h b/nslcd/daemonize.h
index 8eb9885..4287ea1 100644
--- a/nslcd/daemonize.h
+++ b/nslcd/daemonize.h
@@ -29,7 +29,7 @@
    - (re)set proper signal handlers and signal mask
    - sanitise the environment
    - fork() / setsid() / fork() to detach from terminal, become process
-     leader and run in the background (see daemonize_demon() for that)
+     leader and run in the background (see daemonize_daemon() for that)
    - reconnect stdin/stdout/stderr to /dev/null (see
      daemonize_redirect_stdio() for that)
    - set the umask to a reasonable value
@@ -53,7 +53,7 @@ void daemonize_redirect_stdio(void);
    - in the first child call setsid() to detach from any terminal and
      create an independent session
    - keep the parent process waiting until a call to daemonize_ready() is
-     done by the deamon process
+     done by the daemon process
    This function returns either an error which indicates that the
    daemonizing failed for some reason (usually sets errno), or returns
    without error indicating that the process has been daemonized. */
diff --git a/nslcd/invalidator.c b/nslcd/invalidator.c
index 7e8e415..b94dc22 100644
--- a/nslcd/invalidator.c
+++ b/nslcd/invalidator.c
@@ -234,7 +234,7 @@ int invalidator_start(void)
     /* we are the child: close the write end and handle requests */
     close(pipefds[1]);
     handle_requests(pipefds[0]);
-    /* the handle function should't return */
+    /* the handle function shouldn't return */
     _exit(EXIT_FAILURE);
   }
   /* we are the parent: close the read end and save the write end */
diff --git a/nslcd/myldap.c b/nslcd/myldap.c
index a07be36..02b9719 100644
--- a/nslcd/myldap.c
+++ b/nslcd/myldap.c
@@ -111,7 +111,7 @@ struct myldap_search {
   MYLDAP_SESSION *session;
   /* indicator that the search is still valid */
   int valid;
-  /* the parameters descibing the search */
+  /* the parameters describing the search */
   const char *base;
   int scope;
   const char *filter;
@@ -119,7 +119,7 @@ struct myldap_search {
   /* a pointer to the current result entry, used for
      freeing resource allocated with that entry */
   MYLDAP_ENTRY *entry;
-  /* LDAP message id for the search, -1 indicates absense of an active search 
*/
+  /* LDAP message id for the search, -1 indicates absence of an active search 
*/
   int msgid;
   /* the last result that was returned by ldap_result() */
   LDAPMessage *msg;
@@ -127,7 +127,7 @@ struct myldap_search {
   struct berval *cookie;
   /* to indicate that we can retry the search from myldap_get_entry() */
   int may_retry_search;
-  /* the number of resutls returned so far */
+  /* the number of results returned so far */
   int count;
 };
 
@@ -1380,7 +1380,7 @@ static int do_retry_search(MYLDAP_SEARCH *search)
         /* update time of failure and figure out when we should retry */
         pthread_mutex_lock(&uris_mutex);
         t = time(NULL);
-        /* update timestaps unless we are doing an authentication search */
+        /* update timestamps unless we are doing an authentication search */
         if (search->session->binddn[0] == '\0')
         {
           if (current_uri->firstfail == 0)
@@ -1757,7 +1757,7 @@ const char *myldap_get_dn(MYLDAP_ENTRY *entry)
     errno = EINVAL;
     return "unknown";
   }
-  /* if we don't have it yet, retreive it */
+  /* if we don't have it yet, retrieve it */
   if ((entry->dn == NULL) && (entry->search->valid))
   {
     entry->dn = ldap_get_dn(entry->search->session->ld, entry->search->msg);
@@ -1792,7 +1792,7 @@ char *myldap_cpy_dn(MYLDAP_ENTRY *entry, char *buf, 
size_t buflen)
   return buf;
 }
 
-/* Perform ranged retreival of attributes.
+/* Perform ranged retrieval of attributes.
    http://msdn.microsoft.com/en-us/library/aa367017(vs.85).aspx
    http://www.tkk.fi/cc/docs/kerberos/draft-kashi-incremental-00.txt */
 static char **myldap_get_ranged_values(MYLDAP_ENTRY *entry, const char *attr)
@@ -1919,7 +1919,7 @@ const char **myldap_get_values(MYLDAP_ENTRY *entry, const 
char *attr)
   {
     if (ldap_get_option(entry->search->session->ld, LDAP_OPT_ERROR_NUMBER, 
&rc) != LDAP_SUCCESS)
       rc = LDAP_UNAVAILABLE;
-    /* ignore decoding errors as they are just nonexisting attribute values */
+    /* ignore decoding errors as they are just non-existing attribute values */
     if (rc == LDAP_DECODING_ERROR)
     {
       rc = LDAP_SUCCESS;
@@ -2027,7 +2027,7 @@ const char **myldap_get_values_len(MYLDAP_ENTRY *entry, 
const char *attr)
   {
     if (ldap_get_option(entry->search->session->ld, LDAP_OPT_ERROR_NUMBER, 
&rc) != LDAP_SUCCESS)
       rc = LDAP_UNAVAILABLE;
-    /* ignore decoding errors as they are just nonexisting attribute values */
+    /* ignore decoding errors as they are just non-existing attribute values */
     if (rc == LDAP_DECODING_ERROR)
     {
       rc = LDAP_SUCCESS;
diff --git a/nslcd/myldap.h b/nslcd/myldap.h
index 62c9350..c5c4229 100644
--- a/nslcd/myldap.h
+++ b/nslcd/myldap.h
@@ -25,7 +25,7 @@
    out of using the OpenLDAP library. Memory management, paging, reconnect
    logic, idle timeout of connections, etc is taken care of by the module.
 
-   Use of this module is very straightforeward. You first have to create a
+   Use of this module is very straightforward. You first have to create a
    session (with myldap_create_session()), with this session you can start
    searches (with myldap_search()), from a search you can get entries (with
    myldap_get_entry()) from the LDAP database and from these entries you can
@@ -108,7 +108,7 @@ void myldap_search_close(MYLDAP_SEARCH *search);
 /* Get an entry from the result set, going over all results (returns NULL if
    no more entries are available). Note that any memory allocated to return
    information about the previous entry (e.g. with myldap_get_values()) is
-   freed with this call. The search is autoamtically closed when no more
+   freed with this call. The search is automatically closed when no more
    results are available. The function returns an LDAP status code in the
    location pointed to by rcp if it is non-NULL. */
 MUST_USE MYLDAP_ENTRY *myldap_get_entry(MYLDAP_SEARCH *search, int *rcp);
@@ -141,7 +141,7 @@ MUST_USE const char ***myldap_get_deref_values(MYLDAP_ENTRY 
*entry,
 /* Get the RDN's value: eg. if the DN was cn=lukeh, ou=People, dc=example,
    dc=com getrdnvalue(entry, cn) would return lukeh. If the attribute was not
    found in the DN or if some error occurs NULL is returned. This method may
-   be used to get the "most authorative" value for an attribute. */
+   be used to get the "most authoritative" value for an attribute. */
 MUST_USE const char *myldap_get_rdn_value(MYLDAP_ENTRY *entry, const char 
*attr);
 
 /* Just like myldap_get_rdn_value() but use the supplied character sequence
diff --git a/nslcd/pam.c b/nslcd/pam.c
index e7e994a..7093e7c 100644
--- a/nslcd/pam.c
+++ b/nslcd/pam.c
@@ -232,7 +232,7 @@ static int try_bind(const char *userdn, const char 
*password,
       search_vars_free(dict);
     }
   }
-  /* log any authentication, search or authorsiation messages */
+  /* log any authentication, search or authorisation messages */
   if (rc != LDAP_SUCCESS)
     log_log(LOG_WARNING, "%s: %s", userdn, ldap_err2string(rc));
   if ((msg != NULL) && (msg[0] != '\0'))
diff --git a/nslcd/passwd.c b/nslcd/passwd.c
index 016fb73..a4e2678 100644
--- a/nslcd/passwd.c
+++ b/nslcd/passwd.c
@@ -268,7 +268,7 @@ char *lookup_dn2uid(MYLDAP_SESSION *session, const char 
*dn, int *rcp,
   return uid;
 }
 
-/* Translate the DN into a user name. This function tries several aproaches
+/* Translate the DN into a user name. This function tries several approaches
    at getting the user name, including looking in the DN for a uid attribute,
    looking in the cache and falling back to looking up a uid attribute in a
    LDAP query. */
diff --git a/nss/common.h b/nss/common.h
index 82b3d49..3d8986e 100644
--- a/nss/common.h
+++ b/nss/common.h
@@ -48,7 +48,7 @@
 
 /* These are macros for handling read and write problems, they are
    NSS specific due to the return code so are defined here. They
-   genrally close the open file, set an error code and return with
+   generally close the open file, set an error code and return with
    an error status. */
 
 /* Macro is called to handle errors in opening a client connection. */
@@ -83,7 +83,7 @@
   return NSS_STATUS_NOTFOUND;
 
 /* These are some general macros that are used to build parts of the
-   genral macros below. */
+   general macros below. */
 
 /* check to see if we should answer NSS requests */
 #define NSS_AVAILCHECK                                                      \
diff --git a/nss/hosts.c b/nss/hosts.c
index 5f12bc7..d34740f 100644
--- a/nss/hosts.c
+++ b/nss/hosts.c
@@ -162,7 +162,7 @@ nss_status_t NSS_NAME(gethostbyname2_r)(const char *name, 
int af,
 }
 
 /* this function just calls the gethostbyname2() variant with the address
-   familiy set */
+   family set */
 nss_status_t NSS_NAME(gethostbyname_r)(const char *name,
                                        struct hostent *result, char *buffer,
                                        size_t buflen, int *errnop,
@@ -173,10 +173,10 @@ nss_status_t NSS_NAME(gethostbyname_r)(const char *name,
 }
 
 /* this function looks up a single host entry and returns all the addresses
-   associated with the host in a single address familiy
+   associated with the host in a single address family
    addr            - IN  - the address to look up
    len             - IN  - the size of the addr struct
-   af              - IN  - address familty the address is specified as
+   af              - IN  - address family the address is specified as
    result          - OUT - entry found
    buffer,buflen   - OUT - buffer to store allocated stuff on
    errnop,h_errnop - OUT - for reporting errors */
diff --git a/nss/prototypes.h b/nss/prototypes.h
index 37a9824..e27ddc1 100644
--- a/nss/prototypes.h
+++ b/nss/prototypes.h
@@ -25,7 +25,7 @@
 
 #include "compat/nss_compat.h"
 
-/* flag to gloabally disable lookups (all _nss_ldap_*() functions will return
+/* flag to globally disable lookups (all _nss_ldap_*() functions will return
    NSS_STATUS_UNAVAIL */
 extern int NSS_NAME(enablelookups);
 
@@ -135,7 +135,7 @@ nss_status_t NSS_NAME(endspent)(void);
 
 #ifdef NSS_FLAVOUR_SOLARIS
 
-/* helper marcos to do casts */
+/* helper macros to do casts */
 #define NSS_ARGS(args) ((nss_XbyY_args_t *)args)
 #define LDAP_BE(be) ((struct nss_ldap_backend*)(be))
 
diff --git a/pam/common.h b/pam/common.h
index 0cde6c7..ae09c6b 100644
--- a/pam/common.h
+++ b/pam/common.h
@@ -30,7 +30,7 @@
 
 /* These are macros for handling read and write problems, they are
    PAM specific due to the return code so are defined here. They
-   genrally close the open file, set an error code and return with
+   generally close the open file, set an error code and return with
    an error status. */
 
 /* Macro is called to handle errors in opening a client connection. */
diff --git a/tests/common.h b/tests/common.h
index 500f740..fb6ca8f 100644
--- a/tests/common.h
+++ b/tests/common.h
@@ -43,7 +43,7 @@
 #endif
 #endif /* not HAVE___ASSERT_FAIL */
 
-/* extra assertion function that epxects both strings to be the same
+/* extra assertion function that expects both strings to be the same
    (special macro because strcmp() can be a macro that turns ugly in assert) */
 #define assertstreq(str1, str2)                                             \
   (assertstreq_impl(str1, str2,                                             \
diff --git a/tests/test_pynslcd_cache.py b/tests/test_pynslcd_cache.py
index dcabb04..8d3d02a 100755
--- a/tests/test_pynslcd_cache.py
+++ b/tests/test_pynslcd_cache.py
@@ -29,7 +29,7 @@ sys.path.insert(1, os.path.abspath(os.path.join(sys.path[0], 
'..', 'pynslcd')))
 sys.path.insert(2, os.path.abspath(os.path.join('..', 'pynslcd')))
 
 
-# TODO: think about case-sesitivity of cache searches (have tests for that)
+# TODO: think about case-sensitivity of cache searches (have tests for that)
 
 
 class TestAlias(unittest.TestCase):
diff --git a/tests/test_tio.c b/tests/test_tio.c
index a89381a..a005354 100644
--- a/tests/test_tio.c
+++ b/tests/test_tio.c
@@ -347,7 +347,7 @@ static void test_timeout_writer(void)
   /* the error should be timeout */
   assert(saved_errno == ETIME);
   /* close the files */
-  assertok(tio_close(wfp) != 0); /* fails because of bufferred data */
+  assertok(tio_close(wfp) != 0); /* fails because of buffered data */
   assertok(fclose(rfp) == 0);
 }
 
diff --git a/utils/getent.py b/utils/getent.py
index 1de53c9..7f4cf7e 100755
--- a/utils/getent.py
+++ b/utils/getent.py
@@ -169,7 +169,7 @@ def getent_hosts(database, keys=None):
 
 
 def _read_netgroup(con):
-    """Read netgroup name, members and tripples from stream."""
+    """Read netgroup name, members and triples from stream."""
     name = con.read_string()
     members = []
     tripples = []

-----------------------------------------------------------------------

Summary of changes:
 NEWS                        |  2 +-
 common/expr.c               |  4 ++--
 common/nslcd-prot.c         |  2 +-
 common/nslcd-prot.h         | 20 ++++++++++----------
 common/tio.c                |  6 +++---
 compat/attrs.h              |  2 +-
 compat/ether.c              |  2 +-
 compat/getopt_long.c        |  8 ++++----
 compat/getopt_long.h        |  8 ++++----
 compat/getpeercred.h        |  2 +-
 compat/nss_compat.h         |  2 +-
 configure.ac                |  2 +-
 man/nslcd.conf.5.xml        |  6 +++---
 nslcd.h                     |  6 +++---
 nslcd/attmap.h              |  4 ++--
 nslcd/common.h              |  4 ++--
 nslcd/daemonize.h           |  4 ++--
 nslcd/invalidator.c         |  2 +-
 nslcd/myldap.c              | 16 ++++++++--------
 nslcd/myldap.h              |  6 +++---
 nslcd/pam.c                 |  2 +-
 nslcd/passwd.c              |  2 +-
 nss/common.h                |  4 ++--
 nss/hosts.c                 |  6 +++---
 nss/prototypes.h            |  4 ++--
 pam/common.h                |  2 +-
 tests/common.h              |  2 +-
 tests/test_pynslcd_cache.py |  2 +-
 tests/test_tio.c            |  2 +-
 utils/getent.py             |  2 +-
 30 files changed, 68 insertions(+), 68 deletions(-)


hooks/post-receive
diff --git a/common/nslcd-prot.h b/common/nslcd-prot.h
index 649be89..ecad8df 100644
--- a/common/nslcd-prot.h
+++ b/common/nslcd-prot.h
@@ -29,7 +29,7 @@
 #include "tio.h"
 
 /* If you use these macros you should define the following macros to
-   handle error conditions (these marcos should clean up and return from the
+   handle error conditions (these macros should clean up and return from the
    function):
      ERROR_OUT_WRITEERROR(fp)
      ERROR_OUT_READERROR(fp)
@@ -37,9 +37,9 @@
      ERROR_OUT_NOSUCCESS(fp) */
 
 
 /* Debugging marcos that can be used to enable detailed protocol logging,
    pass -DDEBUG_PROT to do overall protocol debugging, and -DDEBUG_PROT_DUMP
-   to dump the actual bytestream. */
+   to dump the actual byte stream. */
 
 #ifdef DEBUG_PROT
 /* define a debugging macro to output logging */
@@ -74,7 +74,7 @@ static void debug_dump(const void *ptr, size_t size)
 #endif /* not DEBUG_PROT_DUMP */
 
 
 /* WRITE marcos, used for writing data, on write error they will
    call the ERROR_OUT_WRITEERROR macro
    these macros may require the availability of the following
    variables:
@@ -224,10 +224,10 @@ static void debug_dump(const void *ptr, size_t size)
 #define BUF_SKIP(sz)                                                        \
   bufptr += (size_t)(sz);
 
-/* move BUF_CUR foreward so that it is aligned to the specified
+/* move BUF_CUR forward so that it is aligned to the specified
    type width */
 #define BUF_ALIGN(fp, type)                                                 \
-  /* figure out number of bytes to skip foreward */                         \
+  /* figure out number of bytes to skip forward */                         \
   tmp2int32 = (sizeof(type) - ((BUF_CUR - (char *)NULL) % sizeof(type)))    \
               % sizeof(type);                                               \
   /* check and skip */                                                      \
@@ -275,14 +275,14 @@ static void debug_dump(const void *ptr, size_t size)
   (field) = BUF_CUR;                                                        \
   BUF_SKIP(tmpint32 + 1);
 
 /* read an array from a stram and store it as a null-terminated
    array list (size for the array is allocated) */
 #define READ_BUF_STRINGLIST(fp, arr)                                        \
   /* read the number of entries */                                          \
   READ(fp, &tmp3int32, sizeof(int32_t));                                    \
   tmp3int32 = ntohl(tmp3int32);                                             \
   DEBUG_PRINT("READ_STRLST: var="__STRING(arr)" num=%d", (int)tmp3int32);   \
-  /* allocate room for *char[num + 1] */                                      \
+  /* allocate room for *char[num + 1] */                                    \
   BUF_ALLOC(fp, arr, char *, tmp3int32 + 1);                                \
   /* read all entries */                                                    \
   for (tmp2int32 = 0; tmp2int32 < tmp3int32; tmp2int32++)                   \
@@ -295,7 +295,7 @@ static void debug_dump(const void *ptr, size_t size)
 
 /* SKIP macros for skipping over certain parts of the protocol stream. */
 
-/* skip a number of bytes foreward */
+/* skip a number of bytes forward */
 #define SKIP(fp, sz)                                                        \
   DEBUG_PRINT("READ       : skip %d bytes", (int)(sz));                     \
   /* read (skip) the specified number of bytes */                           \
@@ -327,7 +327,7 @@ static void debug_dump(const void *ptr, size_t size)
   }
 
 
 /* These are functions and macors for performing common operations in
    the nslcd request/response protocol. */
 
 /* returns a socket to the server or NULL on error (see errno),
@@ -37,9 +37,9 @@
 
 
-/* Debugging marcos that can be used to enable detailed protocol logging,
+/* Debugging macros that can be used to enable detailed protocol logging,
    pass -DDEBUG_PROT to do overall protocol debugging, and -DDEBUG_PROT_DUMP
@@ -74,7 +74,7 @@ static void debug_dump(const void *ptr, size_t size)
 
 
-/* WRITE marcos, used for writing data, on write error they will
+/* WRITE macros, used for writing data, on write error they will
    call the ERROR_OUT_WRITEERROR macro
    these macros may require the availability of the following
@@ -275,14 +275,14 @@ static void debug_dump(const void *ptr, size_t size)
   BUF_SKIP(tmpint32 + 1);
 
-/* read an array from a stram and store it as a null-terminated
+/* read an array from a stream and store it as a null-terminated
    array list (size for the array is allocated) */
 #define READ_BUF_STRINGLIST(fp, arr)                                        \
@@ -327,7 +327,7 @@ static void debug_dump(const void *ptr, size_t size)
 
 
-/* These are functions and macors for performing common operations in
+/* These are functions and macros for performing common operations in
    the nslcd request/response protocol. */
 
-- 
nss-pam-ldapd